EXPORTS
	Write8__12TConfigSpaceUlUc @ 1 NONAME R3UNUSED ; TConfigSpace::Write8(unsigned long, unsigned char)
	CreateChunk__3PciiRP12DPlatChunkHwiUiRUl @ 2 NONAME ; Pci::CreateChunk(int, DPlatChunkHw *&, int, unsigned int, unsigned long &)
	CreateChunk__3PciiRP6DChunkR16TChunkCreateInfoUiUiRUl @ 3 NONAME ; Pci::CreateChunk(int, DChunk *&, TChunkCreateInfo &, unsigned int, unsigned int, unsigned long &)
	CreateMapping__3PciiUliRUl @ 4 NONAME ; Pci::CreateMapping(int, unsigned long, int, unsigned long &)
	GetConfigSpace__12TPciFunction @ 5 NONAME R3UNUSED ; TPciFunction::GetConfigSpace(void)
	GetConfigSpace__3Pcii @ 6 NONAME R3UNUSED ; Pci::GetConfigSpace(int)
	GetMemorySpace__12TPciFunctioni @ 7 NONAME R3UNUSED ; TPciFunction::GetMemorySpace(int)
	GetMemorySpace__3Pciii @ 8 NONAME R3UNUSED ; Pci::GetMemorySpace(int, int)
	GetPciAddress__3PciiRUl @ 9 NONAME R3UNUSED ; Pci::GetPciAddress(int, unsigned long &)
	GetPhysicalAddress__3PciiRUl @ 10 NONAME R3UNUSED ; Pci::GetPhysicalAddress(int, unsigned long &)
	Modify16__12TConfigSpaceUlUsUs @ 11 NONAME ; TConfigSpace::Modify16(unsigned long, unsigned short, unsigned short)
	Modify32__12TConfigSpaceUlUlUl @ 12 NONAME ; TConfigSpace::Modify32(unsigned long, unsigned long, unsigned long)
	Modify8__12TConfigSpaceUlUcUc @ 13 NONAME ; TConfigSpace::Modify8(unsigned long, unsigned char, unsigned char)
	Probe__3PciRt6RArray1ZiUsUs @ 14 NONAME R3UNUSED ; Pci::Probe(RArray<int> &, unsigned short, unsigned short)
	Read16__12TConfigSpaceUl @ 15 NONAME R3UNUSED ; TConfigSpace::Read16(unsigned long)
	Read32__12TConfigSpaceUl @ 16 NONAME R3UNUSED ; TConfigSpace::Read32(unsigned long)
	Read8__12TConfigSpaceUl @ 17 NONAME R3UNUSED ; TConfigSpace::Read8(unsigned long)
	RemoveChunk__3PciiP12DPlatChunkHw @ 18 NONAME R3UNUSED ; Pci::RemoveChunk(int, DPlatChunkHw *)
	RemoveMapping__3PciiUl @ 19 NONAME R3UNUSED ; Pci::RemoveMapping(int, unsigned long)
	Size__10TAddrSpace @ 20 NONAME R3UNUSED ; TAddrSpace::Size(void)
	Write16__12TConfigSpaceUlUs @ 21 NONAME R3UNUSED ; TConfigSpace::Write16(unsigned long, unsigned short)
	Write32__12TConfigSpaceUlUl @ 22 NONAME R3UNUSED ; TConfigSpace::Write32(unsigned long, unsigned long)
	ChunkCleanupCallback__3PciP13TChunkCleanup @ 23 NONAME R3UNUSED ; Pci::ChunkCleanupCallback(TChunkCleanup *)

